==> style-o-matic-1.1.37.tgz: package/es/components/Grid/GridColumn.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import _ from "lodash";
import React from "react";
import classNames from "classnames";
import { CoreComponent, getValidProps, getCorePropTypes, getCorePropDefaults, ROLE } from "../../lib";

var GridColumn = (_temp = _class = function (_CoreComponent) {
  _inherits(GridColumn, _CoreComponent);

  function GridColumn() {
    _classCallCheck(this, GridColumn);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  GridColumn.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var classes = {};

    if (!_.isNil(this.props.cols)) {
      classes["span-" + this.props.cols] = true;
    }

    return React.createElement(
      Component,
      _extends({}, props, { className: classNames(className, classes) }),
      children
    );
  };

  return GridColumn;
}(CoreComponent), _class.propTypes = getCorePropTypes({
  cols: ["string", "number"]
}), _class.defaultProps = getCorePropDefaults({
  uirole: ROLE.COLUMN,
  cols: 12,
  textAlign: "left"
}), _temp);


export default GridColumn;

==> style-o-matic-1.2.0.tgz: package/es/components/Grid/GridColumn.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @memberof components
 * @todo Write sub-component documentation
 * @author Steven Jackson
 */
import React from "react";
import _ from "lodash";
import classNames from "classnames";
import { CoreComponent, getValidProps, setCorePropTypes, setCorePropDefaults, ROLE } from "../../lib";

var GridColumn = (_temp = _class = function (_CoreComponent) {
  _inherits(GridColumn, _CoreComponent);

  function GridColumn() {
    _classCallCheck(this, GridColumn);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  GridColumn.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var classes = {};

    if (!_.isNil(this.props.cols)) {
      classes["span-" + this.props.cols] = true;
    }

    return React.createElement(
      Component,
      _extends({}, props, { className: classNames(className, classes) }),
      children
    );
  };

  return GridColumn;
}(CoreComponent), _class.propTypes = setCorePropTypes({
  cols: ["string", "number"]
}), _class.defaultProps = setCorePropDefaults({
  uirole: ROLE.COLUMN,
  cols: 12
}), _temp);


export default GridColumn;
